a = int(input('Enter the first number'))
b = int(input('Enter the second number'))
def addition(a,b):
    print(a+b)

def subtraction(a,b):
    print(a-b)

def multiplication(a,b):
    print(a*b)

def division(a,b):
    print(a/b)

addition(a,b)
subtraction(a,b)
multiplication(a,b)
division(a,b)
